Photo Keeper - 
=========================================

|image_pypi| |image_downloads| |image_license| |passing| |quality| |Coverage Status|

* Free and open-source software: ASL2 license
* Blog: http://virantha.com/category/projects/photokeeper
* Documentation: http://virantha.github.io/photokeeper/html
* Source: https://github.com/virantha/photokeeper

Features
########

* Kitchen
* Sink

Usage:
######

See docs

Installation
############

.. code-block: bash

    $ pip install photokeeper

Disclaimer
##########

The software is distributed on an "AS IS" BASIS, WITHOUT
WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.

.. |image_pypi| image:: https://badge.fury.io/py/photokeeper.png
   :target: https://pypi.python.org/pypi/photokeeper
.. |image_downloads| image:: https://pypip.in/d/photokeeper/badge.png
   :target: https://crate.io/packages/photokeeper?version=latest
.. |image_license| image:: https://pypip.in/license/photokeeper/badge.png
.. |passing| image:: https://scrutinizer-ci.com/g/virantha/photokeeper/badges/build.png?b=master
.. |quality| image:: https://scrutinizer-ci.com/g/virantha/photokeeper/badges/quality-score.png?b=master
.. |Coverage Status| image:: https://coveralls.io/repos/virantha/photokeeper/badge.png?branch=develop
   :target: https://coveralls.io/r/virantha/photokeeper